#! /usr/bin/perl -w

# Mer_Table.pl - produce a HTML table from the 55 Mer Operon proteins.
#
#                Designed to take a FASTA formatted protein sequence 
#                file and create and HTML overview table of sequences 
#                it contains.  Further demonstrates a mix of CGI.pm 
#                subroutine calls and "hard-coded" HTML tags.  Uses a 
#                Hash of Hashes data structure: see "perldoc perldsc" 
#                for further explanation.

use CGI qw/:standard/;	
use strict;

# A hash to store the sequence details.
my %Seq_Details;

# Use a while loop to cycle through the disk-file, one line-at-a-time.
while (<>)
{
    # Skip any lines that are NOT header lines.	
    unless (/^>s[w|p]\|/) 
    {
        next;
    }

    # Split the line on the "|" character, producing three individual values,
    # which are assigned to lexical variables.  Note: the $tmp scalar is 
    # not used.
    my ( $tmp, $Accession, $ID ) = split( /\|/, $_ );

    # Use a regular expression to match the ID code up to the first space,
    # then ignore the rest of the description.

    $ID = $ID =~ m/(^[\w\d]*) /;	

    # Extract everything up to the first '_' as the gene name.
    my $Gene = $ID =~ m/(.*)_/;	

    # Load the determined data into the hash of hashes.
    $Seq_Details{ $Gene }{ $Accession } =  $ID;
}

# Start constructin the HTML page.
print start_html( "Summary of SWISS-PROT 'Mer' Operon Genes" ), "\n";

# Construct the HTML header, level 1.
print h1( "Summary of 'Mer' Genes" );

# Start constructing the table.
print "<TABLE WIDTH=100% BORDER = 2>\n";

print Tr, th( "Gene" ), th( "Accession Codes" ), th( "Gene IDs" ), "\n";

# Now, run through all of the genes.
foreach my $Gene (sort keys %Seq_Details)
{
    # Begin by starting a new table row.
    print "<TR>\n", th ($Gene), "\n<TD>";

    # Print the accession numbers.
    foreach my $Accession (sort keys %{$Seq_Details{$Gene}})
    {
        print code ($Accession), ", " ;
    }

    # End one table cell, start another.
    print "</TD>\n<TD>";

    # Print the IDs.
    foreach my $Accession (keys %{$Seq_Details{$Gene}})
    {
        print code ($Seq_Details{$Gene}{$Accession}), ", " ;
    }
    # End the table cell and the table row.
    print "</TD></TR>\n";
}

# End the table, insert a horizontal rule, add in the date and conclude
# the HTML web page.
print "</TABLE>\n";
print hr;
print i( system( "date" ));
print end_html,"\n";	

