package UsefulUtils;

# UsefulUtils.pm - the useful utilities module from "Bioinformatics,
#                  Biocomputing and Perl".
#
# Version 0.01:    module created to hold drawline.
# Version 0.02:    added the biodb2mysql subroutine.

require Exporter;

our @ISA          = qw( Exporter );

our @EXPORT       = qw();
our @EXPORT_OK    = qw( drawline biodb2mysql );
our %EXPORT_TAGS  = ();                         
                      
our $VERSION      = 0.02;

use constant REPEAT_COUNT => 60;

sub drawline {
    #
    # Given:  a character string and a repeat count.
    # Return: a string that contains the character string 
    #         "repeat count" number of times.
    #
    # Notes:  For maximum flexibility, this routine does NOT include
    #         a newline ("\n") at the end of the line.
    #

    my %arguments = @_;

    my $chars = $arguments{ Pattern } || "-";
    my $count = $arguments{ Count }   || REPEAT_COUNT;

    return $chars x $count;    
}

sub biodb2mysql {
    #
    # Given:  a date in DD-MMM-YYYY format.
    # Return: a date in YYYY-MM-DD format.
    #
    # Notes:  the returned date format is supported by MySQL.
    #

    my $original = shift;
    
    $original =~ /(\d\d)-(\w\w\w)-(\d\d\d\d)/;

    my ( $day, $month, $year ) = ( $1, $2, $3 );

    $month = '01' if $month eq 'JAN'; 
    $month = '02' if $month eq 'FEB'; 
    $month = '03' if $month eq 'MAR'; 
    $month = '04' if $month eq 'APR'; 
    $month = '05' if $month eq 'MAY'; 
    $month = '06' if $month eq 'JUN'; 
    $month = '07' if $month eq 'JUL'; 
    $month = '08' if $month eq 'AUG'; 
    $month = '09' if $month eq 'SEP'; 
    $month = '10' if $month eq 'OCT'; 
    $month = '11' if $month eq 'NOV'; 
    $month = '12' if $month eq 'DEC'; 
    
    return $year . '-' . $month . '-' . $day;
}

1;
